# Version regress

A module to test PyPi versions

## Install
```bash
$ python3 -m pip install version-regress
```

## Usage 
```python3
from version import regress

regress.version()
```

OR

```python3
from version.regress import version

version()
```
